@@ -5,13 +5,13 @@ use warnings;
 package Kavorka::TraitFor::Sub::fresh;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.023';
+our $VERSION   = '0.024';
 
 use Moo::Role;
 use Types::Standard qw(Any);
 use Sub::Identify qw(stash_name);
 use Carp qw(croak);
-use namespace::clean;
+use namespace::sweep;
 
 before install_sub => sub
 {
