@@ -5,12 +5,12 @@ use warnings;
 package Kavorka::TraitFor::Sub::override;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.023';
+our $VERSION   = '0.024';
 
 use Moo::Role;
 use Types::Standard qw(Any);
 use Carp qw(croak);
-use namespace::clean;
+use namespace::sweep;
 
 before install_sub => sub
 {
